@@ -275,7 +275,8 @@ class Mdadm(object):
             return {
                 "rc": out.rc,
                 "stderr": out.stderr,
-                "stdout": out.stdout
+                "stdout": out.stdout,
+                "command": cmd,
             }
 
     def deviceExists(self, name=None, device=None, uuid=None):
